@@ -106,6 +106,11 @@ void DavGroupwareResource::collectionRemoved( const Akonadi::Collection &collect
     return;
   }
 
+  if ( mCollectionsWithTemporaryError.contains( collection.remoteId() ) ) {
+    cancelTask();
+    return;
+  }
+
   const DavUtils::DavUrl davUrl = Settings::self()->davUrlFromCollectionUrl( collection.remoteId() );
 
   DavCollectionDeleteJob *job = new DavCollectionDeleteJob( davUrl );
@@ -194,6 +199,11 @@ void DavGroupwareResource::retrieveItems( const Akonadi::Collection &collection
     return;
   }
 
+  if ( mCollectionsWithTemporaryError.contains( collection.remoteId() ) ) {
+    cancelTask();
+    return;
+  }
+
   const DavUtils::DavUrl davUrl = Settings::self()->davUrlFromCollectionUrl( collection.remoteId() );
 
   if ( !davUrl.url().isValid() ) {
@@ -220,6 +230,11 @@ bool DavGroupwareResource::retrieveItem( const Akonadi::Item &item, const QSet<Q
     return false;
   }
 
+  if ( mCollectionsWithTemporaryError.contains( item.parentCollection().remoteId() ) ) {
+    cancelTask();
+    return false;
+  }
+
   const DavUtils::DavUrl davUrl = Settings::self()->davUrlFromCollectionUrl( item.parentCollection().remoteId(), item.remoteId() );
 
   DavItem davItem;
@@ -247,6 +262,11 @@ void DavGroupwareResource::itemAdded( const Akonadi::Item &item, const Akonadi::
     return;
   }
 
+  if ( mCollectionsWithTemporaryError.contains( collection.remoteId() ) ) {
+    cancelTask();
+    return;
+  }
+
   const QString basePath = collection.remoteId();
   if ( basePath.isEmpty() ) {
     kError() << "Invalid remote id for collection " << collection.id() << " = " << collection.remoteId();
@@ -323,6 +343,11 @@ void DavGroupwareResource::itemChanged( const Akonadi::Item &item, const QSet<QB
     return;
   }
 
+  if ( mCollectionsWithTemporaryError.contains( item.parentCollection().remoteId() ) ) {
+    cancelTask();
+    return;
+  }
+
   const DavUtils::DavUrl davUrl = Settings::self()->davUrlFromCollectionUrl( item.parentCollection().remoteId(), item.remoteId() );
 
   QByteArray rawData;
@@ -367,6 +392,11 @@ void DavGroupwareResource::itemRemoved( const Akonadi::Item &item )
     return;
   }
 
+  if ( mCollectionsWithTemporaryError.contains( item.parentCollection().remoteId() ) ) {
+    cancelTask();
+    return;
+  }
+
   const DavUtils::DavUrl davUrl = Settings::self()->davUrlFromCollectionUrl( item.parentCollection().remoteId(), item.remoteId() );
 
   DavItem davItem;
@@ -406,20 +436,42 @@ void DavGroupwareResource::onCollectionRemovedFinished( KJob *job )
 
 void DavGroupwareResource::onRetrieveCollectionsFinished( KJob *job )
 {
-  if ( job->error() ) {
+  const DavCollectionsMultiFetchJob *fetchJob = qobject_cast<DavCollectionsMultiFetchJob*>( job );
+
+  if ( job->error() && fetchJob->urlsWithTemporaryError().isEmpty() ) {
+    kWarning() << "Unable to fetch collections" << job->error() << job->errorText();
     cancelTask( i18n( "Unable to retrieve collections: %1", job->errorText() ) );
     return;
   }
 
-  const DavCollectionsMultiFetchJob *fetchJob = qobject_cast<DavCollectionsMultiFetchJob*>( job );
-
   Akonadi::Collection::List collections;
   collections << mDavCollectionRoot;
 
+  foreach ( const DavUtils::DavUrl &davUrl, fetchJob->urlsWithTemporaryError() )
+  {
+    KUrl url = davUrl.url();
+    url.setUser( QString() );
+    QStringList urls = Settings::self()->mappedCollections( davUrl.protocol(), url.prettyUrl() );
+    mCollectionsWithTemporaryError << urls;
+
+    foreach ( const QString &url, urls ) {
+      kWarning() << "Temporary error with collection" << url;
+      Akonadi::Collection collection;
+      collection.setParentCollection( mDavCollectionRoot );
+      collection.setRemoteId( url );
+      collections << collection;
+    }
+  }
+
   const DavCollection::List davCollections = fetchJob->collections();
   QSet<QString> seenCollectionsNames;
 
   foreach ( const DavCollection &davCollection, davCollections ) {
+    if ( mCollectionsWithTemporaryError.contains( davCollection.url() ) ) {
+      kWarning() << davCollection.url() << "is now available";
+      mCollectionsWithTemporaryError.removeOne( davCollection.url() );
+    }
+
     Akonadi::Collection collection;
     collection.setParentCollection( mDavCollectionRoot );
     collection.setRemoteId( davCollection.url() );
