@@ -42,16 +42,21 @@
 #include <mailtransport/transport.h>
 #include <mailtransport/servertest.h>
 
+#include <kmime/kmime_message.h>
+
 #include <akonadi/collectionfetchjob.h>
 #include <akonadi/kmime/specialmailcollections.h>
 #include <akonadi/kmime/specialmailcollectionsrequestjob.h>
-
+#include <akonadi/resourcesettings.h>
+#include <akonadi/entitydisplayattribute.h>
 #include <kemailsettings.h>
 #include <klocale.h>
 #include <kpushbutton.h>
 #include <kmessagebox.h>
 #include <kuser.h>
+#ifndef IMAPRESOURCE_NO_SOLID
 #include <solid/networking.h>
+#endif
 
 #include <kpimidentities/identitymanager.h>
 #include <kpimidentities/identitycombo.h>
@@ -121,9 +126,6 @@ SetupServer::SetupServer( ImapResource *parentResource, WId parent )
   : KDialog(), m_parentResource( parentResource ), m_ui(new Ui::SetupServerView), m_serverTest(0),
     m_subscriptionsChanged(false), m_shouldClearCache(false), mValidator( this )
 {
-#ifdef KDEPIM_MOBILE_UI
-  setButtonsOrientation( Qt::Vertical );
-#endif
   Settings::self()->setWinId( parent );
   m_ui->setupUi( mainWidget() );
   m_ui->safeImapGroup->setId( m_ui->noRadio, KIMAP::LoginJob::Unencrypted );
@@ -141,14 +143,16 @@ SetupServer::SetupServer( ImapResource *parentResource, WId parent )
   m_ui->testProgress->hide();
   m_ui->accountName->setFocus();
   m_ui->checkInterval->setSuffix( ki18np( " minute", " minutes" ) );
+  m_ui->checkInterval->setRange( Akonadi::ResourceSettings::self()->minimumCheckInterval(), 10000, 1 );
 
   // regex for evaluating a valid server name/ip
   mValidator.setRegExp( QRegExp( "[A-Za-z0-9-_:.]*" ) );
   m_ui->imapServer->setValidator( &mValidator );
 
   m_ui->folderRequester->setMimeTypeFilter(
-    QStringList() << QLatin1String( "message/rfc822" ) );
+    QStringList() << KMime::Message::mimeType() );
   m_ui->folderRequester->setAccessRightsFilter( Akonadi::Collection::CanChangeItem | Akonadi::Collection::CanCreateItem | Akonadi::Collection::CanDeleteItem );
+  m_ui->folderRequester->changeCollectionDialogOptions( Akonadi::CollectionDialog::AllowToCreateNewChildCollection );
   m_identityManager = new KPIMIdentities::IdentityManager( false, this, "mIdentityManager" );
   m_identityCombobox = new KPIMIdentities::IdentityCombo( m_identityManager, this );
   m_ui->identityLabel->setBuddy( m_identityCombobox );
@@ -179,9 +183,11 @@ SetupServer::SetupServer( ImapResource *parentResource, WId parent )
   readSettings();
   slotTestChanged();
   slotComplete();
+#ifndef IMAPRESOURCE_NO_SOLID
   connect( Solid::Networking::notifier(),
            SIGNAL( statusChanged( Solid::Networking::Status ) ),
            SLOT( slotTestChanged() ) );
+#endif
   connect( this, SIGNAL( applyClicked() ),
            SLOT( applySettings() ) );
   connect( this, SIGNAL( okClicked() ),
@@ -272,6 +278,12 @@ void SetupServer::applySettings()
   Settings::self()->setSieveVacationFilename( m_vacationFileName );
 
   Settings::self()->setTrashCollection( m_ui->folderRequester->collection().id() );
+  Akonadi::Collection trash = m_ui->folderRequester->collection();
+  Akonadi::EntityDisplayAttribute *attribute =  trash.attribute<Akonadi::EntityDisplayAttribute>( Akonadi::Entity::AddIfMissing );
+  attribute->setIconName( QLatin1String( "user-trash" ) );
+  new Akonadi::CollectionModifyJob( trash );
+
+
 
   Settings::self()->setAutomaticExpungeEnabled( m_ui->autoExpungeCheck->isChecked() );
   Settings::self()->setUseDefaultIdentity( m_ui->useDefaultIdentityCheck->isChecked() );
@@ -287,14 +299,12 @@ void SetupServer::applySettings()
   kDebug() << "wrote" << m_ui->imapServer->text() << m_ui->userName->text() << m_ui->safeImapGroup->checkedId();
 
   if ( m_oldResourceName != m_ui->accountName->text() && !m_ui->accountName->text().isEmpty() ) {
-    m_parentResource->renameRootCollection( m_ui->accountName->text() );
+    Settings::self()->renameRootCollection( m_ui->accountName->text() );
   }
 }
 
 void SetupServer::readSettings()
 {
-  if ( m_parentResource->name() == m_parentResource->identifier() )
-    m_parentResource->setName( i18n( "IMAP Account" ) );
   m_ui->accountName->setText( m_parentResource->name() );
   m_oldResourceName = m_ui->accountName->text();
 
@@ -400,7 +410,9 @@ void SetupServer::slotTest()
 
   delete m_serverTest;
   m_serverTest = new MailTransport::ServerTest( this );
+#ifndef QT_NO_CURSOR
   qApp->setOverrideCursor( Qt::BusyCursor );
+#endif
 
   QString server = m_ui->imapServer->text();
   int port = m_ui->portSpin->value();
@@ -425,7 +437,9 @@ void SetupServer::slotFinished( QList<int> testResult )
 {
   kDebug() << testResult;
 
+#ifndef QT_NO_CURSOR
   qApp->restoreOverrideCursor();
+#endif
   enableButtonOk( true );
 
   using namespace MailTransport;
@@ -540,7 +554,6 @@ void SetupServer::slotManageSubscriptions()
   account.setPort( m_ui->portSpin->value() );
 
   account.setUserName( m_ui->userName->text() );
-  account.setName( m_ui->imapServer->text() + '/' + m_ui->userName->text() );
   account.setSubscriptionEnabled( m_ui->subscriptionEnabled->isChecked() );
 
   account.setEncryptionMode(
@@ -549,10 +562,10 @@ void SetupServer::slotManageSubscriptions()
 
   account.setAuthenticationMode( Settings::mapTransportAuthToKimap( getCurrentAuthMode( m_ui->authenticationCombo ) ) );
 
-  m_subscriptionsChanged = false;
-  SubscriptionDialog *subscriptions = new SubscriptionDialog( this, i18n("Serverside Subscription..."),
-                                                              &account, m_ui->password->text(),
-                                                              m_subscriptionsChanged );
+  SubscriptionDialog *subscriptions = new SubscriptionDialog( this );
+  subscriptions->setCaption(  i18n( "Serverside Subscription..." ) );
+  subscriptions->connectAccount( account, m_ui->password->text() );
+  m_subscriptionsChanged = subscriptions->isSubscriptionChanged();
 
   subscriptions->exec();
 
