@@ -24,12 +24,13 @@
 #include <akonadi/itemdeletejob.h>
 #include <akonadi/itemfetchjob.h>
 #include <akonadi/itemfetchscope.h>
+#include <akonadi/collection.h>
 
 #include <kdebug.h>
 #include <kmime/kmime_codecs.h>
-#include <kcal/comparisonvisitor.h>
-#include <kcal/calformat.h>
-#include <kcal/kcalmimetypevisitor.h>
+
+#include <kcalcore/calformat.h>
+
 #include <libkdepim-copy/kincidencechooser.h>
 #include <KLocale>
 
@@ -37,11 +38,11 @@
 #include <QDomDocument>
 
 
-IncidenceHandler::IncidenceHandler() : KolabHandler(), m_calendar( QString::fromLatin1("UTC") )
+IncidenceHandler::IncidenceHandler( const Akonadi::Collection &imapCollection )
+  : KolabHandler( imapCollection), m_calendar( QString::fromLatin1("UTC") )
 {
 }
 
-
 IncidenceHandler::~IncidenceHandler()
 {
 }
@@ -51,25 +52,41 @@ Akonadi::Item::List IncidenceHandler::translateItems(const Akonadi::Item::List &
 {
   kDebug() << "translateItems" << items.size();
   Akonadi::Item::List newItems;
-  Q_FOREACH(Akonadi::Item item, items)
+  Q_FOREACH(const Akonadi::Item &item, items)
   {
-    if (!item.hasPayload<MessagePtr>()) {
+    if (!item.hasPayload<KMime::Message::Ptr>()) {
       kWarning() << "Payload is not a MessagePtr!";
       continue;
     }
-    MessagePtr payload = item.payload<MessagePtr>();
-    KCal::Incidence *inc = incidenceFromKolab(payload);
-    kDebug() << "KCal::Incidence " << inc;
+    const KMime::Message::Ptr payload = item.payload<KMime::Message::Ptr>();
+    KCalCore::Incidence::Ptr inc = incidenceFromKolab( payload );
+    kDebug() << "KCalCore::Incidence " << inc;
     if (inc) {
-      Akonadi::KCalMimeTypeVisitor visitor;
-      inc->accept( visitor );
-      IncidencePtr incidencePtr(inc);
+      KCalCore::Incidence::Ptr incidencePtr(inc);
       if (m_uidMap.contains(incidencePtr->uid())) {
+        StoredItem storedItem = m_uidMap[incidencePtr->uid()];
+        kDebug() << "Conflict detected for incidence uid  " << incidencePtr->uid()
+                 << " for imap item id = " << item.id()
+                 << " and the other imap item id is "
+                 << storedItem.id << "; imap collection is "
+                 << m_imapCollection.name()
+                 << m_imapCollection.id()
+                 << "; collection has rights "
+                 << m_imapCollection.rights();
+
+        const Akonadi::Collection::Rights requiredRights = Akonadi::Collection::CanDeleteItem |
+                                                           Akonadi::Collection::CanCreateItem;
+
+        if ( ( m_imapCollection.rights() & requiredRights ) != requiredRights ) {
+          kDebug() << "Skipping conflict resolution, no rights on collection " << m_imapCollection.name();
+          continue;
+        }
+
         ConflictResolution res = resolveConflict(incidencePtr);
         kDebug() << "ConflictResolution " << res;
         if (res == Local) {
           m_uidMap.remove(incidencePtr->uid());
-          incidencePtr.reset();
+          incidencePtr = KCalCore::Incidence::Ptr();
           emit deleteItemFromImap(item);
           continue;
         } else if (res == Remote) {
@@ -77,19 +94,22 @@ Akonadi::Item::List IncidenceHandler::translateItems(const Akonadi::Item::List &
           emit deleteItemFromImap(it);
         } else if (res == Both) {
           incidencePtr->setSummary( i18n("Copy of: %1", incidencePtr->summary() ) );
-          incidencePtr->setUid( KCal::CalFormat::createUniqueId() );
-          Akonadi::Item copiedItem( visitor.mimeType() );
+          incidencePtr->setUid( KCalCore::CalFormat::createUniqueId() );
+          Akonadi::Item copiedItem( incidencePtr->mimeType() );
           incidenceToItem(incidencePtr, copiedItem);
           Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob( item );
           job->fetchScope().fetchFullPayload();
           if (job->exec()) {
             emit addItemToImap(copiedItem, job->items()[0].storageCollectionId());
           }
+          // we can't do newItem.setRemoteId(..) yet because we don't have copiedItem.id()
+          // it's being added to imap, so we continue.
+          continue;
         }
       }
       m_uidMap[incidencePtr->uid()] = StoredItem(item.id(), incidencePtr);
       kDebug() << "Add to uidMap: " << incidencePtr->uid() << item.id() << incidencePtr;
-      Akonadi::Item newItem( visitor.mimeType() );
+      Akonadi::Item newItem( incidencePtr->mimeType() );
       newItem.setPayload(incidencePtr);
       newItem.setRemoteId(QString::number(item.id()));
       newItems << newItem;
@@ -99,7 +119,7 @@ Akonadi::Item::List IncidenceHandler::translateItems(const Akonadi::Item::List &
   return newItems;
 }
 
-IncidenceHandler::ConflictResolution IncidenceHandler::resolveConflict( IncidencePtr inc)
+IncidenceHandler::ConflictResolution IncidenceHandler::resolveConflict( const KCalCore::Incidence::Ptr &inc)
 {
   /*
   if ( ! isResolveConflictSet() ) {
@@ -109,19 +129,17 @@ IncidenceHandler::ConflictResolution IncidenceHandler::resolveConflict( Incidenc
 }
   */
   const QString origUid = inc->uid();
-  KCal::Incidence* local = m_uidMap[origUid].incidence.get();
-  KCal::Incidence* localIncidence = 0;
-  KCal::Incidence* addedIncidence = 0;
-  KCal::Incidence*  result = 0;
-  if ( local ) {
-    KCal::ComparisonVisitor visitor;
-    kDebug() << "Compare  " << local << inc.get();
-    if ( visitor.compare( local, inc.get() ) ) {
-        // real duplicate, remove the second one
+  KCalCore::Incidence::Ptr localIncidence = m_uidMap[origUid].incidence;
+  KCalCore::Incidence::Ptr addedIncidence = inc;
+  KCalCore::Incidence::Ptr result;
+  if ( localIncidence ) {
+    kDebug() << "Compare  " << localIncidence << addedIncidence;
+    if ( *localIncidence.data() == *addedIncidence.data() ) {
+      // real duplicate, remove the second one
       return Duplicate;
     } else {
       KPIM::KIncidenceChooser* ch = new KPIM::KIncidenceChooser();
-      ch->setIncidence( local ,inc.get() );
+      ch->setIncidence( localIncidence, addedIncidence );
       if ( KPIM::KIncidenceChooser::chooseMode == KPIM::KIncidenceChooser::ask ) {
         connect ( this, SIGNAL( useGlobalMode() ), ch, SLOT (  useGlobalMode() ) );
         if ( ch->exec() )
@@ -132,12 +150,12 @@ IncidenceHandler::ConflictResolution IncidenceHandler::resolveConflict( Incidenc
       delete ch;
     }
   } else {
-      // nothing there locally, just take the new one. Can't Happen (TM)
-    result = inc.get();
+    // nothing there locally, just take the new one. Can't Happen (TM)
+    result = addedIncidence;
   }
-  if ( result == local ) { //take local
+  if ( result == localIncidence ) { //take local
     return Local;
-  } else  if ( result == inc.get() ) { //take remote (inc)
+  } else  if ( result == addedIncidence ) { //take remote (inc)
     return Remote;
   } else if ( result == 0 ) { // take both
     return Both;
@@ -148,62 +166,35 @@ IncidenceHandler::ConflictResolution IncidenceHandler::resolveConflict( Incidenc
 void IncidenceHandler::toKolabFormat(const Akonadi::Item& item, Akonadi::Item &imapItem)
 {
   kDebug() << "toKolabFormat";
-  IncidencePtr incidencePtr;
-  if (item.hasPayload<IncidencePtr>()) {
-    incidencePtr = item.payload<IncidencePtr>();
+  KCalCore::Incidence::Ptr incidencePtr;
+  if (item.hasPayload<KCalCore::Incidence::Ptr>()) {
+    incidencePtr = item.payload<KCalCore::Incidence::Ptr>();
   }
   kDebug() << "item payload: " << item.payloadData();
   incidenceToItem(incidencePtr, imapItem);
 }
 
-void IncidenceHandler::incidenceToItem(IncidencePtr incidencePtr, Akonadi::Item &imapItem)
+void IncidenceHandler::incidenceToItem(const KCalCore::Incidence::Ptr &incidencePtr, Akonadi::Item &imapItem)
 {
-  if (!incidencePtr.get())
-  {
+  if ( !incidencePtr ) {
     imapItem.setPayloadFromData("");
     return;
   }
   imapItem.setMimeType( "message/rfc822" );
 
-  MessagePtr message(new KMime::Message);
-  QString header;
-  header += "From: " + incidencePtr->organizer().fullName() + "<" + incidencePtr->organizer().email() + ">\n";
-  header += "Subject: " + incidencePtr->uid() + "\n";
-  header += "Date: " + QDateTime::currentDateTime().toString(Qt::TextDate) + "\n";
-  header += "User-Agent: Akonadi Kolab Proxy Resource \n";
-  header += "MIME-Version: 1.0\n";
-  header += "X-Kolab-Type: " + m_mimeType + "\n\n\n";
-  message->setHead(header.toLatin1());
+  KMime::Message::Ptr message = createMessage( m_mimeType );
+  message->from()->addAddress( incidencePtr->organizer()->email().toUtf8(), incidencePtr->organizer()->name() );
+  message->subject()->fromUnicodeString( incidencePtr->uid(), "utf-8" );
 
-  KMime::Content *content = new KMime::Content();
-  QByteArray contentData = QByteArray("Content-Type: text/plain; charset=\"us-ascii\"\nContent-Transfer-Encoding: 7bit\n\n") +
-      "This is a Kolab Groupware object.\n" +
-      "To view this object you will need an email client that can understand the Kolab Groupware format.\n" +
-      "For a list of such email clients please visit\n"
-      "http://www.kolab.org/kolab2-clients.html\n";
-  content->setContent(contentData);
-  message->addContent(content);
-
-  content = new KMime::Content();
-  header = "Content-Type: " + m_mimeType + "; name=\"kolab.xml\"\n";
-  header += "Content-Transfer-Encoding: quoted-printable\n";
-  header += "Content-Disposition: attachment; filename=\"kolab.xml\"";
-  content->setHead(header.toLatin1());
-  KMime::Codec *codec = KMime::Codec::codecForName( "quoted-printable" );
-  content->setBody(codec->encode(incidenceToXml(incidencePtr.get())));
-  message->addContent(content);
-
-  Q_FOREACH (KCal::Attachment *attachment, incidencePtr->attachments()) {
-    header = "Content-Type: "  +attachment->mimeType() + "; name=\""  + attachment->label() + "\"\n";
-    header += "Content-Transfer-Encoding: base64\n";
-    header += "Content-Disposition: attachment; filename=\"" + attachment->label() + "\"";
-    content = new KMime::Content();
-    content->setHead(header.toLatin1());
-    content->setBody(attachment->data());
-    message->addContent(content);
+  KMime::Content *content = createMainPart( m_mimeType, incidenceToXml(incidencePtr ) );
+  message->addContent( content );
 
+  Q_FOREACH (KCalCore::Attachment::Ptr attachment, incidencePtr->attachments()) {
+    content = createAttachmentPart( attachment->mimeType(), attachment->label(), attachment->decodedData() );
+    message->addContent( content );
   }
 
+  message->assemble();
   imapItem.setPayload(message);
 }
 
@@ -224,14 +215,34 @@ void IncidenceHandler::itemDeleted(const Akonadi::Item &item)
 
 void IncidenceHandler::itemAdded(const Akonadi::Item& item)
 {
-  if (!item.hasPayload<MessagePtr>()) {
+  if (!item.hasPayload<KMime::Message::Ptr>()) {
     kWarning() << "Payload is not a MessagePtr!";
     return;
   }
-  MessagePtr payload = item.payload<MessagePtr>();
-  KCal::Incidence *e = incidenceFromKolab(payload);
-  IncidencePtr incidence(e);
+  KMime::Message::Ptr payload = item.payload<KMime::Message::Ptr>();
+  KCalCore::Incidence::Ptr e = incidenceFromKolab(payload);
+  if ( !e )
+    return;
+  const KCalCore::Incidence::Ptr incidence(e);
   m_uidMap[e->uid()] = StoredItem(item.id(), incidence);
   kDebug() << "Add to uidMap: " << incidence->uid() << item.id() << incidence;
 }
 
+
+void IncidenceHandler::attachmentsFromKolab(const KMime::Message::Ptr& data, const QDomDocument &xmlDoc,
+                                            const KCalCore::Incidence::Ptr &incidence)
+{
+  QDomNodeList nodes = xmlDoc.elementsByTagName("inline-attachment");
+  for (int i = 0; i < nodes.size(); i++ ) {
+    const QString name = nodes.at(i).toElement().text();
+    QByteArray type;
+    KMime::Content *content = findContentByName(data, name, type);
+    if (!content) // guard against malformed events with non-existant attachments
+        continue;
+    const QByteArray c = content->decodedContent().toBase64();
+    KCalCore::Attachment::Ptr attachment( new KCalCore::Attachment( c, QString::fromLatin1( type ) ) );
+    attachment->setLabel( name );
+    incidence->addAttachment(attachment);
+    kDebug() << "ATTACHEMENT NAME" << name << type;
+  }
+}
