@@ -27,7 +27,6 @@
 #include "settings.h"
 #include "settingsadaptor.h"
 
-#include "kmindexreader/messagestatus.h"
 
 #include "filestore/collectioncreatejob.h"
 #include "filestore/collectiondeletejob.h"
@@ -46,13 +45,16 @@
 #include <akonadi/changerecorder.h>
 #include <akonadi/itemfetchjob.h>
 #include <akonadi/itemfetchscope.h>
+#include <akonadi/kmime/messagestatus.h>
 #include <akonadi/itemmodifyjob.h>
 #include <akonadi/collectionfetchscope.h>
 
 #include <kmime/kmime_message.h>
 
+#ifndef KDEPIM_NO_NEPOMUK
 #include <Nepomuk/Tag>
 #include <Nepomuk/Resource>
+#endif
 
 #include <KDebug>
 #include <KLocale>
@@ -172,10 +174,18 @@ void MixedMaildirResource::itemChanged( const Item &item, const QSet<QByteArray>
   }
 
   // TODO this is probably something the store should decide
-  const bool payloadChanged = parts.contains( Item::FullPayload ) ||
-                              parts.contains( MessagePart::Header ) ||
-                              parts.contains( MessagePart::Envelope ) ||
-                              parts.contains( MessagePart::Body );
+  bool payloadChanged = false;
+  Q_FOREACH( const QByteArray &part, parts )  {
+    if( part.startsWith("PLD:") ) {
+      payloadChanged = true;
+      break;
+    }
+  }
+
+  if ( !payloadChanged ) {
+    changeProcessed();
+    return; //ignore flag-only changes
+  }
 
   Item storeItem( item );
   storeItem.setRemoteId( mCompactHelper->currentRemoteId( item ) );
@@ -494,7 +504,7 @@ void MixedMaildirResource::retrieveItemsResult( KJob *job )
   KJob* deleteJob = 0;
   Item::List items;
   Q_FOREACH( const Item &item, fetchJob->items() ) {
-    KPIM::MessageStatus status;
+    Akonadi::MessageStatus status;
     status.setStatusFromFlags( item.flags() );
     if ( status.isDeleted() ) {
       deleteJob = mStore->deleteItem( item );
@@ -807,6 +817,7 @@ void MixedMaildirResource::tagFetchJobResult( KJob *job )
   Q_ASSERT( !fetchJob->items().isEmpty() );
 
   const Item item = fetchJob->items()[ 0 ];
+#ifndef KDEPIM_NO_NEPOMUK
   const QStringList tagList = job->property( "tagList" ).value<QStringList>();
   kDebug() << "Tagging item" << item.url() << "with" << tagList;
 
@@ -821,6 +832,7 @@ void MixedMaildirResource::tagFetchJobResult( KJob *job )
 
   Nepomuk::Resource nepomukResource( item.url() );
   nepomukResource.setTags( nepomukTags );
+#endif
 
   processNextTagContext();
 }
