@@ -1,6 +1,8 @@
 /*
  *   Copyright (C) 2000 Espen Sand, espen@kde.org
  *   Copyright 2009 Thomas McGuire <mcguire@kde.org>
+ *   Copyright (c) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+ *   Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -19,21 +21,24 @@
  */
 
 // Local includes
-#include "settings.h"
-#include "settingsadaptor.h"
 #include "accountdialog.h"
 #include "pop3resource.h"
+#include "settings.h"
+#include "settingsadaptor.h"
 
 // KDEPIMLIBS includes
 #include <Akonadi/Collection>
 #include <Akonadi/CollectionFetchJob>
 #include <akonadi/kmime/specialmailcollections.h>
 #include <akonadi/kmime/specialmailcollectionsrequestjob.h>
+#include <akonadi/resourcesettings.h>
 #include <Mailtransport/ServerTest>
 
 // KDELIBS includes
+#include <KEMailSettings>
 #include <KMessageBox>
 #include <KProtocolInfo>
+#include <KUser>
 #include <KWindowSystem>
 #include <kwallet.h>
 
@@ -49,12 +54,16 @@ public:
   inline BusyCursorHelper( QObject *parent )
          : QObject( parent )
   {
+#ifndef QT_NO_CURSOR
     qApp->setOverrideCursor( Qt::BusyCursor );
+#endif
   }
 
   inline ~BusyCursorHelper()
   {
+#ifndef QT_NO_CURSOR
     qApp->restoreOverrideCursor();
+#endif
   }
 };
 
@@ -90,12 +99,12 @@ void AccountDialog::setupWidgets()
   setupUi( page );
   setMainWidget( page );
 
-  connect( passwordEdit, SIGNAL( textEdited( const QString& ) ),
-           this, SLOT( slotPopPasswordChanged( const QString& ) ) );
-
   // only letters, digits, '-', '.', ':' (IPv6) and '_' (for Windows
   // compatibility) are allowed
   hostEdit->setValidator( &mValidator );
+  intervalSpin->setSuffix( ki18np( " minute", " minutes" ) );
+
+  intervalSpin->setRange( ResourceSettings::self()->minimumCheckInterval(), 10000, 1 );
 
   connect( leaveOnServerCheck, SIGNAL( clicked() ),
            this, SLOT( slotLeaveOnServerClicked() ) );
@@ -132,26 +141,13 @@ void AccountDialog::setupWidgets()
   connect( intervalCheck, SIGNAL(toggled(bool)),
            this, SLOT(slotEnablePopInterval(bool)) );
 
-  // FIXME: Does this still work for non-ioslave POP3?
-  if ( KProtocolInfo::capabilities("pop3").contains("SASL") == 0 )
-  {
-    authNTLM->hide();
-    authGSSAPI->hide();
-  }
-  authButtonGroup = new QButtonGroup();
-  authButtonGroup->addButton( authUser );
-  authButtonGroup->addButton( authLogin );
-  authButtonGroup->addButton( authPlain );
-  authButtonGroup->addButton( authCRAM_MD5 );
-  authButtonGroup->addButton( authDigestMd5 );
-  authButtonGroup->addButton( authNTLM );
-  authButtonGroup->addButton( authGSSAPI );
-  authButtonGroup->addButton( authAPOP );
+  populateDefaultAuthenticationOptions();
 
   folderRequester->setMimeTypeFilter(
       QStringList() << QLatin1String( "message/rfc822" ) );
   folderRequester->setFrameStyle( QFrame::NoFrame );
   folderRequester->setAccessRightsFilter( Akonadi::Collection::CanCreateItem );
+  folderRequester->changeCollectionDialogOptions( Akonadi::CollectionDialog::AllowToCreateNewChildCollection );
 
   connect( usePipeliningCheck, SIGNAL(clicked()),
            SLOT(slotPipeliningClicked()) );
@@ -160,7 +156,6 @@ void AccountDialog::setupWidgets()
           SLOT(slotFontChanged()));
 
   // FIXME: Hide widgets which are not supported yet
-  includeInCheck->hide();
   filterOnServerCheck->hide();
   filterOnServerSizeSpin->hide();
 }
@@ -172,13 +167,16 @@ void AccountDialog::loadSettings()
 
   nameEdit->setText( mParentResource->name() );
   nameEdit->setFocus();
-  loginEdit->setText( Settings::self()->login() );
+  loginEdit->setText( !Settings::self()->login().isEmpty() ? Settings::self()->login() :
+                      KUser().loginName() );
+
+  hostEdit->setText(
+    !Settings::self()->host().isEmpty() ? Settings::self()->host() :
+    KEMailSettings().getSetting( KEMailSettings::InServer ) );
   hostEdit->setText( Settings::self()->host() );
   portEdit->setValue( Settings::self()->port() );
   precommand->setText( Settings::self()->precommand() );
   usePipeliningCheck->setChecked( Settings::self()->pipelining() );
-  storePasswordCheck->setChecked( Settings::self()->storePassword() );
-  mInitallyStorePassword = Settings::self()->storePassword();
   leaveOnServerCheck->setChecked( Settings::self()->leaveOnServer() );
   leaveOnServerDaysCheck->setEnabled( Settings::self()->leaveOnServer() );
   leaveOnServerDaysCheck->setChecked( Settings::self()->leaveOnServerDays() >= 1 );
@@ -197,26 +195,12 @@ void AccountDialog::loadSettings()
   intervalCheck->setChecked( Settings::self()->intervalCheckEnabled() );
   intervalSpin->setValue( Settings::self()->intervalCheckInterval() );
   intervalSpin->setEnabled( Settings::self()->intervalCheckEnabled() );
-  if (Settings::self()->useSSL())
-    encryptionSSL->setChecked( true );
-  else if (Settings::self()->useTLS())
-    encryptionTLS->setChecked( true );
-  else encryptionNone->setChecked( true );
-  if (Settings::self()->authenticationMethod() == "LOGIN")
-    authLogin->setChecked( true );
-  else if (Settings::self()->authenticationMethod() == "PLAIN")
-    authPlain->setChecked( true );
-  else if (Settings::self()->authenticationMethod() == "CRAM-MD5")
-    authCRAM_MD5->setChecked( true );
-  else if (Settings::self()->authenticationMethod() == "DIGEST-MD5")
-    authDigestMd5->setChecked( true );
-  else if (Settings::self()->authenticationMethod() == "NTLM")
-    authNTLM->setChecked( true );
-  else if (Settings::self()->authenticationMethod() == "GSSAPI")
-    authGSSAPI->setChecked( true );
-  else if (Settings::self()->authenticationMethod() == "APOP")
-    authAPOP->setChecked( true );
-  else authUser->setChecked( true );
+
+  const int authenticationMethod = Settings::self()->authenticationMethod();
+  authCombo->setCurrentIndex( authCombo->findData( authenticationMethod ) );
+  encryptionNone->setChecked( !Settings::self()->useSSL() && !Settings::self()->useTLS() );
+  encryptionSSL->setChecked( Settings::self()->useSSL() );
+  encryptionTLS->setChecked( Settings::self()->useTLS() );
 
   slotEnableLeaveOnServerDays( leaveOnServerDaysCheck->isEnabled() ?
                                Settings::self()->leaveOnServerDays() >= 1 : 0);
@@ -245,15 +229,12 @@ void AccountDialog::loadSettings()
     connect ( requestJob, SIGNAL(result(KJob*)),
               this, SLOT(localFolderRequestJobFinished(KJob*)) );
   }
-  folderRequester->setEnabled( false );
 
-  if ( Settings::storePassword() ) {
-    mWallet = Wallet::openWallet( Wallet::NetworkWallet(), winId(),
-                                  Wallet::Asynchronous );
-    connect( mWallet, SIGNAL(walletOpened(bool)),
-             this, SLOT(walletOpenedForLoading(bool)) );
-    passwordEdit->setEnabled( false );
-  }
+  mWallet = Wallet::openWallet( Wallet::NetworkWallet(), winId(),
+                                Wallet::Asynchronous );
+  connect( mWallet, SIGNAL(walletOpened(bool)),
+           this, SLOT(walletOpenedForLoading(bool)) );
+  passwordEdit->setEnabled( false );
 }
 
 void AccountDialog::walletOpenedForLoading( bool success )
@@ -271,13 +252,10 @@ void AccountDialog::walletOpenedForLoading( bool success )
     }
   }
   else {
-    storePasswordCheck->setChecked( false );
     kWarning() << "Failed to open wallet for loading the password.";
   }
 
   passwordEdit->setEnabled( true );
-  delete mWallet;
-  mWallet = 0;
 }
 
 void AccountDialog::walletOpenedForSaving( bool success )
@@ -286,19 +264,22 @@ void AccountDialog::walletOpenedForSaving( bool success )
     if ( mWallet && mWallet->isOpen() ) {
 
       // Remove the password from the wallet if the user doesn't want to store it
-      if ( !Settings::self()->storePassword() && mWallet->hasFolder( "pop3" ) ) {
+      if ( passwordEdit->text().isEmpty() && mWallet->hasFolder( "pop3" ) ) {
         mWallet->setFolder( "pop3" );
         mWallet->removeEntry( mParentResource->identifier() );
       }
 
       // Store the password in the wallet if the user wants that
-      else if ( Settings::self()->storePassword() ) {
+      else if ( !passwordEdit->text().isEmpty() ) {
         if ( !mWallet->hasFolder( "pop3" ) ) {
           mWallet->createFolder( "pop3" );
         }
         mWallet->setFolder( "pop3" );
         mWallet->writePassword( mParentResource->identifier(), passwordEdit->text() );
       }
+
+      mParentResource->clearCachedPassword();
+      Settings::self()->setStorePassword( !passwordEdit->text().isEmpty() );
     }
     else {
       kWarning() << "Wallet not open.";
@@ -306,7 +287,7 @@ void AccountDialog::walletOpenedForSaving( bool success )
   }
   else {
     // Should we alert the user here?
-    kWarning() << "Failed to open wallet for loading the password.";
+    kWarning() << "Failed to open wallet for saving the password.";
   }
 
   delete mWallet;
@@ -384,22 +365,13 @@ void AccountDialog::slotPipeliningClicked()
 
 void AccountDialog::slotPopEncryptionChanged( int id )
 {
+  kDebug() << "setting port";
   // adjust port
   if ( id == Transport::EnumEncryption::SSL || portEdit->value() == 995 )
     portEdit->setValue( ( id == Transport::EnumEncryption::SSL ) ? 995 : 110 );
 
-  enablePopFeatures();
-  const QAbstractButton *old = authButtonGroup->checkedButton();
-  if ( old && !old->isEnabled() )
-    checkHighest( authButtonGroup );
-}
-
-void AccountDialog::slotPopPasswordChanged( const QString& text )
-{
-  if ( text.isEmpty() )
-    storePasswordCheck->setCheckState( Qt::Unchecked );
-  else
-    storePasswordCheck->setCheckState( Qt::Checked );
+  kDebug() << "port set ";
+  enablePopFeatures(); // removes invalid auth options from the combobox
 }
 
 void AccountDialog::slotCheckPopCapabilities()
@@ -414,6 +386,7 @@ void AccountDialog::slotCheckPopCapabilities()
   mServerTest = new ServerTest( this );
   BusyCursorHelper *busyCursorHelper = new BusyCursorHelper( mServerTest );
   mServerTest->setProgressBar( checkCapabilitiesProgress );
+  enableButtonOk( false );
   checkCapabilitiesStack->setCurrentIndex( 1 );
   Transport::EnumEncryption::type encryptionType;
   if ( encryptionSSL->isChecked() )
@@ -427,6 +400,7 @@ void AccountDialog::slotCheckPopCapabilities()
            this, SLOT( slotPopCapabilities(QList<int>) ) );
   connect( mServerTest, SIGNAL( finished(QList<int>) ),
            busyCursorHelper, SLOT( deleteLater() ) );
+
   mServerTest->start();
   mServerTestFailed = false;
 }
@@ -434,6 +408,11 @@ void AccountDialog::slotCheckPopCapabilities()
 void AccountDialog::slotPopCapabilities( QList<int> encryptionTypes )
 {
   checkCapabilitiesStack->setCurrentIndex( 0 );
+  enableButtonOk( true );
+
+  // if both fail, popup a dialog
+  if ( !mServerTest->isNormalPossible() && !mServerTest->isSecurePossible() )
+    KMessageBox::sorry( this, i18n( "Unable to connect to the server, please verify the server address." ) );
 
   // If the servertest did not find any useable authentication modes, assume the
   // connection failed and don't disable any of the radioboxes.
@@ -462,13 +441,10 @@ void AccountDialog::enablePopFeatures()
   if ( encryptionButtonGroup->checkedId() == Transport::EnumEncryption::TLS )
     supportedAuths = mServerTest->tlsProtocols();
 
-  authPlain->setEnabled( supportedAuths.contains( Transport::EnumAuthenticationType::PLAIN ) );
-  authLogin->setEnabled( supportedAuths.contains( Transport::EnumAuthenticationType::LOGIN ) );
-  authCRAM_MD5->setEnabled( supportedAuths.contains( Transport::EnumAuthenticationType::CRAM_MD5 ) );
-  authDigestMd5->setEnabled( supportedAuths.contains( Transport::EnumAuthenticationType::DIGEST_MD5 ) );
-  authNTLM->setEnabled( supportedAuths.contains( Transport::EnumAuthenticationType::NTLM ) );
-  authGSSAPI->setEnabled( supportedAuths.contains( Transport::EnumAuthenticationType::GSSAPI ) );
-  authAPOP->setEnabled( supportedAuths.contains( Transport::EnumAuthenticationType::APOP ) );
+  authCombo->clear();
+  foreach( int prot, supportedAuths ) {
+    authCombo->addItem( Transport::authenticationTypeString( prot ) , prot );
+  }
 
   if ( mServerTest && !mServerTest->capabilities().contains( ServerTest::Pipelining ) &&
        usePipeliningCheck->isChecked() ) {
@@ -522,6 +498,27 @@ void AccountDialog::enablePopFeatures()
   }
 }
 
+static void addAuthenticationItem( QComboBox *combo,
+                                   int authenticationType )
+{
+  combo->addItem( Transport::authenticationTypeString( authenticationType ),
+                  QVariant( authenticationType ) );
+}
+
+void AccountDialog::populateDefaultAuthenticationOptions()
+{
+  authCombo->clear();
+  addAuthenticationItem( authCombo, Transport::EnumAuthenticationType::CLEAR );
+  addAuthenticationItem( authCombo, Transport::EnumAuthenticationType::LOGIN );
+  addAuthenticationItem( authCombo, Transport::EnumAuthenticationType::PLAIN );
+  addAuthenticationItem( authCombo, Transport::EnumAuthenticationType::CRAM_MD5 );
+  addAuthenticationItem( authCombo, Transport::EnumAuthenticationType::DIGEST_MD5 );
+  addAuthenticationItem( authCombo, Transport::EnumAuthenticationType::NTLM );
+  addAuthenticationItem( authCombo, Transport::EnumAuthenticationType::GSSAPI );
+  addAuthenticationItem( authCombo, Transport::EnumAuthenticationType::APOP );
+}
+
+
 void AccountDialog::slotLeaveOnServerDaysChanged ( int value )
 {
   leaveOnServerDaysSpin->setSuffix( i18np(" day", " days", value) );
@@ -576,29 +573,10 @@ void AccountDialog::saveSettings()
   Settings::self()->setHost( hostEdit->text().trimmed() );
   Settings::self()->setPort( portEdit->value() );
   Settings::self()->setLogin( loginEdit->text().trimmed() );
-  Settings::self()->setStorePassword( storePasswordCheck->isChecked() );
   Settings::self()->setPrecommand( precommand->text() );
   Settings::self()->setUseSSL( encryptionSSL->isChecked() );
   Settings::self()->setUseTLS( encryptionTLS->isChecked() );
-  if (authUser->isChecked())
-    Settings::self()->setAuthenticationMethod("USER");
-  else if (authLogin->isChecked())
-    Settings::self()->setAuthenticationMethod("LOGIN");
-  else if (authPlain->isChecked())
-    Settings::self()->setAuthenticationMethod("PLAIN");
-  else if (authCRAM_MD5->isChecked())
-    Settings::self()->setAuthenticationMethod("CRAM-MD5");
-  else if (authDigestMd5->isChecked())
-    Settings::self()->setAuthenticationMethod("DIGEST-MD5");
-  else if (authNTLM->isChecked())
-    Settings::self()->setAuthenticationMethod("NTLM");
-  else if (authGSSAPI->isChecked())
-    Settings::self()->setAuthenticationMethod("GSSAPI");
-  else if (authAPOP->isChecked())
-    Settings::self()->setAuthenticationMethod("APOP");
-  else
-    Settings::self()->setAuthenticationMethod("AUTO");
-
+  Settings::self()->setAuthenticationMethod( authCombo->itemData( authCombo->currentIndex() ).toInt() );
   Settings::self()->setPipelining( usePipeliningCheck->isChecked() );
   Settings::self()->setLeaveOnServer( leaveOnServerCheck->isChecked() );
   Settings::self()->setLeaveOnServerDays( leaveOnServerCheck->isChecked() ?
@@ -619,14 +597,22 @@ void AccountDialog::saveSettings()
   // to open it.
   const bool userChangedPassword = mInitalPassword != passwordEdit->text();
   const bool userWantsToDeletePassword =
-      !Settings::self()->storePassword() && mInitallyStorePassword;
+      passwordEdit->text().isEmpty() && userChangedPassword;
 
-  if ( ( Settings::self()->storePassword() && userChangedPassword ) ||
+  if ( ( !passwordEdit->text().isEmpty() && userChangedPassword ) ||
        userWantsToDeletePassword ) {
-    mWallet = Wallet::openWallet( Wallet::NetworkWallet(), winId(),
-                                  Wallet::Asynchronous );
-    connect( mWallet, SIGNAL(walletOpened(bool)),
-             this, SLOT(walletOpenedForSaving(bool)) );
+    kDebug() << mWallet <<  mWallet->isOpen();
+    if( mWallet && mWallet->isOpen() ) {
+      // wallet is already open
+      walletOpenedForSaving( true );
+    } else {
+      // we need to open the wallet
+      kDebug() << "we need to open the wallet";
+      mWallet = Wallet::openWallet( Wallet::NetworkWallet(), winId(),
+                                    Wallet::Asynchronous );
+      connect( mWallet, SIGNAL(walletOpened(bool)),
+              this, SLOT(walletOpenedForSaving(bool)) );
+    }
   }
   else {
     // Neither save nor delete the password, we're done!
@@ -673,7 +659,6 @@ void AccountDialog::slotFontChanged( void )
 void AccountDialog::targetCollectionReceived( Akonadi::Collection::List collections )
 {
   folderRequester->setCollection( collections.first() );
-  folderRequester->setEnabled( true );
 }
 
 void AccountDialog::localFolderRequestJobFinished( KJob *job )
@@ -683,7 +668,6 @@ void AccountDialog::localFolderRequestJobFinished( KJob *job )
     Q_ASSERT( targetCollection.isValid() );
     folderRequester->setCollection( targetCollection );
   }
-  folderRequester->setEnabled( true );
 }
 
 #include "accountdialog.moc"
